import numpy as np
import matplotlib.pyplot as plt
from astropy.timeseries import TimeSeries
from astropy.utils.data import get_pkg_data_filename
from astropy import units as u

filename = get_pkg_data_filename('timeseries/kplr010666592-2009131110544_slc.fits')
ts = TimeSeries.read(filename, format='kepler.fits')

plt.figure(figsize=(10,5))

# Show the original light curve
plt.subplot(1, 2, 1)
plt.plot(ts.time.mjd, ts['sap_flux'], 'k.', markersize=1)
plt.xlabel('Barycentric Modified Julian Date')
plt.ylabel('SAP Flux (e-/s)')

# Find the transit period and fold the light curve
from astropy.timeseries import BoxLeastSquares
periodogram = BoxLeastSquares.from_timeseries(ts, 'sap_flux')
results = periodogram.autopower(0.2 * u.day)
best = np.argmax(results.power)
ts_folded = ts.fold(period=results.period[best],
                    midpoint_epoch=results.transit_time[best])

# Show the folded light curve
plt.subplot(1, 2, 2)
plt.plot(ts_folded.time.jd, ts_folded['sap_flux'], 'k.', markersize=1)
plt.xlabel('Time relative to epoch (days)')
plt.gca().get_yaxis().set_visible(False)