import numpy as np
import matplotlib.pyplot as plt
from astropy.visualization import quantity_support
quantity_support()

from astropy import units as u
from astropy.time import Time
from astropy.coordinates import BarycentricMeanEcliptic, BarycentricTrueEcliptic, ICRS

t = Time('J2018') + np.linspace(-1, 0, 1000)*u.year

bme_origin = BarycentricMeanEcliptic([0]*len(t)*u.deg, [0]*len(t)*u.deg, equinox=t)
bte_origin = BarycentricTrueEcliptic([0]*len(t)*u.deg, [0]*len(t)*u.deg, equinox=t)

im = bme_origin.transform_to(ICRS())
it = bte_origin.transform_to(ICRS())

plt.plot(t.jyear, im.ra.wrap_at(180*u.deg), label='BarycentricMeanEcliptic')
plt.plot(t.jyear, it.ra.wrap_at(180*u.deg), label='BarycentricTrueEcliptic')

plt.xlabel('Julian year')
plt.ylabel('ICRS R.A. of ecliptic origin [{}]'.format(im.ra.unit))
plt.legend(loc=0)